@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import IO, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -193,7 +193,8 @@ class GetBlockResponseTypeDef(_RequiredGetBlockResponseTypeDef, _OptionalGetBloc
 
 
 GetDigestResponseTypeDef = TypedDict(
-    "GetDigestResponseTypeDef", {"Digest": bytes, "DigestTipAddress": "ValueHolderTypeDef"}
+    "GetDigestResponseTypeDef",
+    {"Digest": Union[bytes, IO[bytes]], "DigestTipAddress": "ValueHolderTypeDef"},
 )
 
 _RequiredGetRevisionResponseTypeDef = TypedDict(
